# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('databricks')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def account_id(self) -> Optional[str]:
        return __config__.get('accountId')

    @_builtins.property
    def actions_id_token_request_token(self) -> Optional[str]:
        return __config__.get('actionsIdTokenRequestToken')

    @_builtins.property
    def actions_id_token_request_url(self) -> Optional[str]:
        return __config__.get('actionsIdTokenRequestUrl')

    @_builtins.property
    def audience(self) -> Optional[str]:
        return __config__.get('audience')

    @_builtins.property
    def auth_type(self) -> Optional[str]:
        return __config__.get('authType')

    @_builtins.property
    def azure_client_id(self) -> Optional[str]:
        return __config__.get('azureClientId')

    @_builtins.property
    def azure_client_secret(self) -> Optional[str]:
        return __config__.get('azureClientSecret')

    @_builtins.property
    def azure_environment(self) -> Optional[str]:
        return __config__.get('azureEnvironment')

    @_builtins.property
    def azure_login_app_id(self) -> Optional[str]:
        return __config__.get('azureLoginAppId')

    @_builtins.property
    def azure_tenant_id(self) -> Optional[str]:
        return __config__.get('azureTenantId')

    @_builtins.property
    def azure_use_msi(self) -> Optional[bool]:
        return __config__.get_bool('azureUseMsi')

    @_builtins.property
    def azure_workspace_resource_id(self) -> Optional[str]:
        return __config__.get('azureWorkspaceResourceId')

    @_builtins.property
    def client_id(self) -> Optional[str]:
        return __config__.get('clientId')

    @_builtins.property
    def client_secret(self) -> Optional[str]:
        return __config__.get('clientSecret')

    @_builtins.property
    def cloud(self) -> Optional[str]:
        return __config__.get('cloud')

    @_builtins.property
    def cluster_id(self) -> Optional[str]:
        return __config__.get('clusterId')

    @_builtins.property
    def config_file(self) -> Optional[str]:
        return __config__.get('configFile')

    @_builtins.property
    def databricks_cli_path(self) -> Optional[str]:
        return __config__.get('databricksCliPath')

    @_builtins.property
    def databricks_id_token_filepath(self) -> Optional[str]:
        return __config__.get('databricksIdTokenFilepath')

    @_builtins.property
    def debug_headers(self) -> Optional[bool]:
        return __config__.get_bool('debugHeaders')

    @_builtins.property
    def debug_truncate_bytes(self) -> Optional[int]:
        return __config__.get_int('debugTruncateBytes')

    @_builtins.property
    def disable_oauth_refresh_token(self) -> Optional[bool]:
        return __config__.get_bool('disableOauthRefreshToken')

    @_builtins.property
    def discovery_url(self) -> Optional[str]:
        return __config__.get('discoveryUrl')

    @_builtins.property
    def experimental_is_unified_host(self) -> Optional[bool]:
        return __config__.get_bool('experimentalIsUnifiedHost')

    @_builtins.property
    def google_credentials(self) -> Optional[str]:
        return __config__.get('googleCredentials')

    @_builtins.property
    def google_service_account(self) -> Optional[str]:
        return __config__.get('googleServiceAccount')

    @_builtins.property
    def host(self) -> Optional[str]:
        return __config__.get('host')

    @_builtins.property
    def http_timeout_seconds(self) -> Optional[int]:
        return __config__.get_int('httpTimeoutSeconds')

    @_builtins.property
    def metadata_service_url(self) -> Optional[str]:
        return __config__.get('metadataServiceUrl')

    @_builtins.property
    def oauth_callback_port(self) -> Optional[int]:
        return __config__.get_int('oauthCallbackPort')

    @_builtins.property
    def oidc_token_env(self) -> Optional[str]:
        return __config__.get('oidcTokenEnv')

    @_builtins.property
    def password(self) -> Optional[str]:
        return __config__.get('password')

    @_builtins.property
    def profile(self) -> Optional[str]:
        return __config__.get('profile')

    @_builtins.property
    def rate_limit(self) -> Optional[int]:
        return __config__.get_int('rateLimit')

    @_builtins.property
    def retry_timeout_seconds(self) -> Optional[int]:
        return __config__.get_int('retryTimeoutSeconds')

    @_builtins.property
    def scopes(self) -> Optional[str]:
        return __config__.get('scopes')

    @_builtins.property
    def serverless_compute_id(self) -> Optional[str]:
        return __config__.get('serverlessComputeId')

    @_builtins.property
    def skip_verify(self) -> Optional[bool]:
        return __config__.get_bool('skipVerify')

    @_builtins.property
    def token(self) -> Optional[str]:
        return __config__.get('token')

    @_builtins.property
    def username(self) -> Optional[str]:
        return __config__.get('username')

    @_builtins.property
    def warehouse_id(self) -> Optional[str]:
        return __config__.get('warehouseId')

    @_builtins.property
    def workspace_id(self) -> Optional[str]:
        return __config__.get('workspaceId')

