# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AibiDashboardEmbeddingApprovedDomainsSettingArgs', 'AibiDashboardEmbeddingApprovedDomainsSetting']

@pulumi.input_type
class AibiDashboardEmbeddingApprovedDomainsSettingArgs:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_approved_domains: pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs'],
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AibiDashboardEmbeddingApprovedDomainsSetting resource.
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if setting_name is not None:
            pulumi.set(__self__, "setting_name", setting_name)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']:
        """
        block with following attributes:
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "setting_name")

    @setting_name.setter
    def setting_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "setting_name", value)


@pulumi.input_type
class _AibiDashboardEmbeddingApprovedDomainsSettingState:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AibiDashboardEmbeddingApprovedDomainsSetting resources.
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        if aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if setting_name is not None:
            pulumi.set(__self__, "setting_name", setting_name)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        block with following attributes:
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "etag", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "setting_name")

    @setting_name.setter
    def setting_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "setting_name", value)


@pulumi.type_token("databricks:index/aibiDashboardEmbeddingApprovedDomainsSetting:AibiDashboardEmbeddingApprovedDomainsSetting")
class AibiDashboardEmbeddingApprovedDomainsSetting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']]] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `AibiDashboardEmbeddingApprovedDomainsSetting` resource allows you to specify the list of domains allowed for  [embedding of AI/BI Dashboards](https://learn.microsoft.com/en-us/azure/databricks/dashboards/admin/#manage-dashboard-embedding) into other sites.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.AibiDashboardEmbeddingAccessPolicySetting("this", aibi_dashboard_embedding_access_policy={
            "access_policy_type": "ALLOW_APPROVED_DOMAINS",
        })
        this_aibi_dashboard_embedding_approved_domains_setting = databricks.AibiDashboardEmbeddingApprovedDomainsSetting("this", aibi_dashboard_embedding_approved_domains={
            "approved_domains": ["test.com"],
        },
        opts = pulumi.ResourceOptions(depends_on=[this]))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        - AibiDashboardEmbeddingAccessPolicySetting is used to control embedding policy.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AibiDashboardEmbeddingApprovedDomainsSettingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `AibiDashboardEmbeddingApprovedDomainsSetting` resource allows you to specify the list of domains allowed for  [embedding of AI/BI Dashboards](https://learn.microsoft.com/en-us/azure/databricks/dashboards/admin/#manage-dashboard-embedding) into other sites.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.AibiDashboardEmbeddingAccessPolicySetting("this", aibi_dashboard_embedding_access_policy={
            "access_policy_type": "ALLOW_APPROVED_DOMAINS",
        })
        this_aibi_dashboard_embedding_approved_domains_setting = databricks.AibiDashboardEmbeddingApprovedDomainsSetting("this", aibi_dashboard_embedding_approved_domains={
            "approved_domains": ["test.com"],
        },
        opts = pulumi.ResourceOptions(depends_on=[this]))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        - AibiDashboardEmbeddingAccessPolicySetting is used to control embedding policy.

        :param str resource_name: The name of the resource.
        :param AibiDashboardEmbeddingApprovedDomainsSettingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AibiDashboardEmbeddingApprovedDomainsSettingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 etag: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']]] = None,
                 setting_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AibiDashboardEmbeddingApprovedDomainsSettingArgs.__new__(AibiDashboardEmbeddingApprovedDomainsSettingArgs)

            if aibi_dashboard_embedding_approved_domains is None and not opts.urn:
                raise TypeError("Missing required property 'aibi_dashboard_embedding_approved_domains'")
            __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
            __props__.__dict__["etag"] = etag
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["setting_name"] = setting_name
        super(AibiDashboardEmbeddingApprovedDomainsSetting, __self__).__init__(
            'databricks:index/aibiDashboardEmbeddingApprovedDomainsSetting:AibiDashboardEmbeddingApprovedDomainsSetting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
            etag: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']]] = None,
            setting_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'AibiDashboardEmbeddingApprovedDomainsSetting':
        """
        Get an existing AibiDashboardEmbeddingApprovedDomainsSetting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: block with following attributes:
        :param pulumi.Input[Union['AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgs', 'AibiDashboardEmbeddingApprovedDomainsSettingProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AibiDashboardEmbeddingApprovedDomainsSettingState.__new__(_AibiDashboardEmbeddingApprovedDomainsSettingState)

        __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
        __props__.__dict__["etag"] = etag
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["setting_name"] = setting_name
        return AibiDashboardEmbeddingApprovedDomainsSetting(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> pulumi.Output['outputs.AibiDashboardEmbeddingApprovedDomainsSettingAibiDashboardEmbeddingApprovedDomains']:
        """
        block with following attributes:
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter
    def etag(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "etag")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.AibiDashboardEmbeddingApprovedDomainsSettingProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="settingName")
    def setting_name(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "setting_name")

