# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFeatureEngineeringKafkaConfigsResult',
    'AwaitableGetFeatureEngineeringKafkaConfigsResult',
    'get_feature_engineering_kafka_configs',
    'get_feature_engineering_kafka_configs_output',
]

@pulumi.output_type
class GetFeatureEngineeringKafkaConfigsResult:
    """
    A collection of values returned by getFeatureEngineeringKafkaConfigs.
    """
    def __init__(__self__, id=None, kafka_configs=None, page_size=None, provider_config=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if kafka_configs and not isinstance(kafka_configs, list):
            raise TypeError("Expected argument 'kafka_configs' to be a list")
        pulumi.set(__self__, "kafka_configs", kafka_configs)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="kafkaConfigs")
    def kafka_configs(self) -> Sequence['outputs.GetFeatureEngineeringKafkaConfigsKafkaConfigResult']:
        return pulumi.get(self, "kafka_configs")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetFeatureEngineeringKafkaConfigsProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetFeatureEngineeringKafkaConfigsResult(GetFeatureEngineeringKafkaConfigsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringKafkaConfigsResult(
            id=self.id,
            kafka_configs=self.kafka_configs,
            page_size=self.page_size,
            provider_config=self.provider_config)


def get_feature_engineering_kafka_configs(page_size: Optional[_builtins.int] = None,
                                          provider_config: Optional[Union['GetFeatureEngineeringKafkaConfigsProviderConfigArgs', 'GetFeatureEngineeringKafkaConfigsProviderConfigArgsDict']] = None,
                                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringKafkaConfigsResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.int page_size: The maximum number of results to return
    :param Union['GetFeatureEngineeringKafkaConfigsProviderConfigArgs', 'GetFeatureEngineeringKafkaConfigsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringKafkaConfigs:getFeatureEngineeringKafkaConfigs', __args__, opts=opts, typ=GetFeatureEngineeringKafkaConfigsResult).value

    return AwaitableGetFeatureEngineeringKafkaConfigsResult(
        id=pulumi.get(__ret__, 'id'),
        kafka_configs=pulumi.get(__ret__, 'kafka_configs'),
        page_size=pulumi.get(__ret__, 'page_size'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_feature_engineering_kafka_configs_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                                 provider_config: Optional[pulumi.Input[Optional[Union['GetFeatureEngineeringKafkaConfigsProviderConfigArgs', 'GetFeatureEngineeringKafkaConfigsProviderConfigArgsDict']]]] = None,
                                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringKafkaConfigsResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.int page_size: The maximum number of results to return
    :param Union['GetFeatureEngineeringKafkaConfigsProviderConfigArgs', 'GetFeatureEngineeringKafkaConfigsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringKafkaConfigs:getFeatureEngineeringKafkaConfigs', __args__, opts=opts, typ=GetFeatureEngineeringKafkaConfigsResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringKafkaConfigsResult(
        id=pulumi.get(__response__, 'id'),
        kafka_configs=pulumi.get(__response__, 'kafka_configs'),
        page_size=pulumi.get(__response__, 'page_size'),
        provider_config=pulumi.get(__response__, 'provider_config')))
