# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppSpaceArgs', 'AppSpace']

@pulumi.input_type
class AppSpaceArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AppSpaceProviderConfigArgs']] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a AppSpace resource.
        :param pulumi.Input[_builtins.str] description: The description of the app space
        :param pulumi.Input[_builtins.str] name: The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
               It must be unique within the workspace
        :param pulumi.Input['AppSpaceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]] resources: Resources for the app space. Resources configured at the space level are available to all apps in the space
        :param pulumi.Input[_builtins.str] usage_policy_id: The usage policy ID for managing cost at the space level
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: OAuth scopes for apps in the space
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)
        if user_api_scopes is not None:
            pulumi.set(__self__, "user_api_scopes", user_api_scopes)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the app space
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
        It must be unique within the workspace
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AppSpaceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AppSpaceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]]]:
        """
        Resources for the app space. Resources configured at the space level are available to all apps in the space
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The usage policy ID for managing cost at the space level
        """
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        OAuth scopes for apps in the space
        """
        return pulumi.get(self, "user_api_scopes")

    @user_api_scopes.setter
    def user_api_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_api_scopes", value)


@pulumi.input_type
class _AppSpaceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 creator: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['AppSpaceProviderConfigArgs']] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]]] = None,
                 service_principal_client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
                 service_principal_name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input['AppSpaceStatusArgs']] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 updater: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AppSpace resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - The creation time of the app space. Formatted timestamp in ISO 6801
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the user that created the app space
        :param pulumi.Input[_builtins.str] description: The description of the app space
        :param pulumi.Input[_builtins.str] effective_usage_policy_id: (string) - The effective usage policy ID used by apps in the space
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] effective_user_api_scopes: (list of string) - The effective api scopes granted to the user access token
        :param pulumi.Input[_builtins.str] name: The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
               It must be unique within the workspace
        :param pulumi.Input['AppSpaceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]] resources: Resources for the app space. Resources configured at the space level are available to all apps in the space
        :param pulumi.Input[_builtins.str] service_principal_client_id: (string) - The service principal client ID for the app space
        :param pulumi.Input[_builtins.int] service_principal_id: (integer) - The service principal ID for the app space
        :param pulumi.Input[_builtins.str] service_principal_name: (string) - The service principal name for the app space
        :param pulumi.Input['AppSpaceStatusArgs'] status: (SpaceStatus) - The status of the app space
        :param pulumi.Input[_builtins.str] update_time: (string) - The update time of the app space. Formatted timestamp in ISO 6801
        :param pulumi.Input[_builtins.str] updater: (string) - The email of the user that last updated the app space
        :param pulumi.Input[_builtins.str] usage_policy_id: The usage policy ID for managing cost at the space level
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: OAuth scopes for apps in the space
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if creator is not None:
            pulumi.set(__self__, "creator", creator)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if effective_usage_policy_id is not None:
            pulumi.set(__self__, "effective_usage_policy_id", effective_usage_policy_id)
        if effective_user_api_scopes is not None:
            pulumi.set(__self__, "effective_user_api_scopes", effective_user_api_scopes)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if service_principal_client_id is not None:
            pulumi.set(__self__, "service_principal_client_id", service_principal_client_id)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)
        if service_principal_name is not None:
            pulumi.set(__self__, "service_principal_name", service_principal_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if updater is not None:
            pulumi.set(__self__, "updater", updater)
        if usage_policy_id is not None:
            pulumi.set(__self__, "usage_policy_id", usage_policy_id)
        if user_api_scopes is not None:
            pulumi.set(__self__, "user_api_scopes", user_api_scopes)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The creation time of the app space. Formatted timestamp in ISO 6801
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def creator(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The email of the user that created the app space
        """
        return pulumi.get(self, "creator")

    @creator.setter
    def creator(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "creator", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the app space
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The effective usage policy ID used by apps in the space
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @effective_usage_policy_id.setter
    def effective_usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "effective_usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="effectiveUserApiScopes")
    def effective_user_api_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        (list of string) - The effective api scopes granted to the user access token
        """
        return pulumi.get(self, "effective_user_api_scopes")

    @effective_user_api_scopes.setter
    def effective_user_api_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "effective_user_api_scopes", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
        It must be unique within the workspace
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['AppSpaceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['AppSpaceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]]]:
        """
        Resources for the app space. Resources configured at the space level are available to all apps in the space
        """
        return pulumi.get(self, "resources")

    @resources.setter
    def resources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AppSpaceResourceArgs']]]]):
        pulumi.set(self, "resources", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalClientId")
    def service_principal_client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The service principal client ID for the app space
        """
        return pulumi.get(self, "service_principal_client_id")

    @service_principal_client_id.setter
    def service_principal_client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_principal_client_id", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        (integer) - The service principal ID for the app space
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "service_principal_id", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalName")
    def service_principal_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The service principal name for the app space
        """
        return pulumi.get(self, "service_principal_name")

    @service_principal_name.setter
    def service_principal_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_principal_name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['AppSpaceStatusArgs']]:
        """
        (SpaceStatus) - The status of the app space
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['AppSpaceStatusArgs']]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The update time of the app space. Formatted timestamp in ISO 6801
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter
    def updater(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The email of the user that last updated the app space
        """
        return pulumi.get(self, "updater")

    @updater.setter
    def updater(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updater", value)

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The usage policy ID for managing cost at the space level
        """
        return pulumi.get(self, "usage_policy_id")

    @usage_policy_id.setter
    def usage_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        OAuth scopes for apps in the space
        """
        return pulumi.get(self, "user_api_scopes")

    @user_api_scopes.setter
    def user_api_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_api_scopes", value)


@pulumi.type_token("databricks:index/appSpace:AppSpace")
class AppSpace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AppSpaceProviderConfigArgs', 'AppSpaceProviderConfigArgsDict']]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppSpaceResourceArgs', 'AppSpaceResourceArgsDict']]]]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the app space
        :param pulumi.Input[_builtins.str] name: The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
               It must be unique within the workspace
        :param pulumi.Input[Union['AppSpaceProviderConfigArgs', 'AppSpaceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppSpaceResourceArgs', 'AppSpaceResourceArgsDict']]]] resources: Resources for the app space. Resources configured at the space level are available to all apps in the space
        :param pulumi.Input[_builtins.str] usage_policy_id: The usage policy ID for managing cost at the space level
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: OAuth scopes for apps in the space
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AppSpaceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param AppSpaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppSpaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['AppSpaceProviderConfigArgs', 'AppSpaceProviderConfigArgsDict']]] = None,
                 resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppSpaceResourceArgs', 'AppSpaceResourceArgsDict']]]]] = None,
                 usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppSpaceArgs.__new__(AppSpaceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["resources"] = resources
            __props__.__dict__["usage_policy_id"] = usage_policy_id
            __props__.__dict__["user_api_scopes"] = user_api_scopes
            __props__.__dict__["create_time"] = None
            __props__.__dict__["creator"] = None
            __props__.__dict__["effective_usage_policy_id"] = None
            __props__.__dict__["effective_user_api_scopes"] = None
            __props__.__dict__["service_principal_client_id"] = None
            __props__.__dict__["service_principal_id"] = None
            __props__.__dict__["service_principal_name"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["update_time"] = None
            __props__.__dict__["updater"] = None
        super(AppSpace, __self__).__init__(
            'databricks:index/appSpace:AppSpace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            creator: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            effective_usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            effective_user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['AppSpaceProviderConfigArgs', 'AppSpaceProviderConfigArgsDict']]] = None,
            resources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AppSpaceResourceArgs', 'AppSpaceResourceArgsDict']]]]] = None,
            service_principal_client_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
            service_principal_name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[Union['AppSpaceStatusArgs', 'AppSpaceStatusArgsDict']]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            updater: Optional[pulumi.Input[_builtins.str]] = None,
            usage_policy_id: Optional[pulumi.Input[_builtins.str]] = None,
            user_api_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'AppSpace':
        """
        Get an existing AppSpace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - The creation time of the app space. Formatted timestamp in ISO 6801
        :param pulumi.Input[_builtins.str] creator: (string) - The email of the user that created the app space
        :param pulumi.Input[_builtins.str] description: The description of the app space
        :param pulumi.Input[_builtins.str] effective_usage_policy_id: (string) - The effective usage policy ID used by apps in the space
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] effective_user_api_scopes: (list of string) - The effective api scopes granted to the user access token
        :param pulumi.Input[_builtins.str] name: The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
               It must be unique within the workspace
        :param pulumi.Input[Union['AppSpaceProviderConfigArgs', 'AppSpaceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AppSpaceResourceArgs', 'AppSpaceResourceArgsDict']]]] resources: Resources for the app space. Resources configured at the space level are available to all apps in the space
        :param pulumi.Input[_builtins.str] service_principal_client_id: (string) - The service principal client ID for the app space
        :param pulumi.Input[_builtins.int] service_principal_id: (integer) - The service principal ID for the app space
        :param pulumi.Input[_builtins.str] service_principal_name: (string) - The service principal name for the app space
        :param pulumi.Input[Union['AppSpaceStatusArgs', 'AppSpaceStatusArgsDict']] status: (SpaceStatus) - The status of the app space
        :param pulumi.Input[_builtins.str] update_time: (string) - The update time of the app space. Formatted timestamp in ISO 6801
        :param pulumi.Input[_builtins.str] updater: (string) - The email of the user that last updated the app space
        :param pulumi.Input[_builtins.str] usage_policy_id: The usage policy ID for managing cost at the space level
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_api_scopes: OAuth scopes for apps in the space
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppSpaceState.__new__(_AppSpaceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["creator"] = creator
        __props__.__dict__["description"] = description
        __props__.__dict__["effective_usage_policy_id"] = effective_usage_policy_id
        __props__.__dict__["effective_user_api_scopes"] = effective_user_api_scopes
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["resources"] = resources
        __props__.__dict__["service_principal_client_id"] = service_principal_client_id
        __props__.__dict__["service_principal_id"] = service_principal_id
        __props__.__dict__["service_principal_name"] = service_principal_name
        __props__.__dict__["status"] = status
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["updater"] = updater
        __props__.__dict__["usage_policy_id"] = usage_policy_id
        __props__.__dict__["user_api_scopes"] = user_api_scopes
        return AppSpace(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The creation time of the app space. Formatted timestamp in ISO 6801
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def creator(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The email of the user that created the app space
        """
        return pulumi.get(self, "creator")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the app space
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="effectiveUsagePolicyId")
    def effective_usage_policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The effective usage policy ID used by apps in the space
        """
        return pulumi.get(self, "effective_usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="effectiveUserApiScopes")
    def effective_user_api_scopes(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        (list of string) - The effective api scopes granted to the user access token
        """
        return pulumi.get(self, "effective_user_api_scopes")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the app space. The name must contain only lowercase alphanumeric characters and hyphens.
        It must be unique within the workspace
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.AppSpaceProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> pulumi.Output[Optional[Sequence['outputs.AppSpaceResource']]]:
        """
        Resources for the app space. Resources configured at the space level are available to all apps in the space
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalClientId")
    def service_principal_client_id(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The service principal client ID for the app space
        """
        return pulumi.get(self, "service_principal_client_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Output[_builtins.int]:
        """
        (integer) - The service principal ID for the app space
        """
        return pulumi.get(self, "service_principal_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalName")
    def service_principal_name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The service principal name for the app space
        """
        return pulumi.get(self, "service_principal_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.AppSpaceStatus']:
        """
        (SpaceStatus) - The status of the app space
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The update time of the app space. Formatted timestamp in ISO 6801
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter
    def updater(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The email of the user that last updated the app space
        """
        return pulumi.get(self, "updater")

    @_builtins.property
    @pulumi.getter(name="usagePolicyId")
    def usage_policy_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The usage policy ID for managing cost at the space level
        """
        return pulumi.get(self, "usage_policy_id")

    @_builtins.property
    @pulumi.getter(name="userApiScopes")
    def user_api_scopes(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        OAuth scopes for apps in the space
        """
        return pulumi.get(self, "user_api_scopes")

