# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetEndpointsResult',
    'AwaitableGetEndpointsResult',
    'get_endpoints',
    'get_endpoints_output',
]

@pulumi.output_type
class GetEndpointsResult:
    """
    A collection of values returned by getEndpoints.
    """
    def __init__(__self__, id=None, items=None, page_size=None, parent=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetEndpointsItemResult']:
        return pulumi.get(self, "items")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> _builtins.str:
        return pulumi.get(self, "parent")


class AwaitableGetEndpointsResult(GetEndpointsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointsResult(
            id=self.id,
            items=self.items,
            page_size=self.page_size,
            parent=self.parent)


def get_endpoints(page_size: Optional[_builtins.int] = None,
                  parent: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointsResult:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    Endpoints datasource retrieves a list of all network connectivity endpoints for private access to Databricks workspaces.

    > **Note** This resource can only be used with an account-level provider!

    ## Example Usage

    ### Example for Azure cloud
    This is an example for listing endpoints in Azure cloud:
    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_endpoints(parent="accounts/123e4567-e89b-12d3-a456-426614174000")
    ```


    :param _builtins.str parent: The parent resource name of the account to list endpoints for.
           Format: `accounts/{account_id}`
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['parent'] = parent
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getEndpoints:getEndpoints', __args__, opts=opts, typ=GetEndpointsResult).value

    return AwaitableGetEndpointsResult(
        id=pulumi.get(__ret__, 'id'),
        items=pulumi.get(__ret__, 'items'),
        page_size=pulumi.get(__ret__, 'page_size'),
        parent=pulumi.get(__ret__, 'parent'))
def get_endpoints_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                         parent: Optional[pulumi.Input[_builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointsResult]:
    """
    [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

    Endpoints datasource retrieves a list of all network connectivity endpoints for private access to Databricks workspaces.

    > **Note** This resource can only be used with an account-level provider!

    ## Example Usage

    ### Example for Azure cloud
    This is an example for listing endpoints in Azure cloud:
    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_endpoints(parent="accounts/123e4567-e89b-12d3-a456-426614174000")
    ```


    :param _builtins.str parent: The parent resource name of the account to list endpoints for.
           Format: `accounts/{account_id}`
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['parent'] = parent
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getEndpoints:getEndpoints', __args__, opts=opts, typ=GetEndpointsResult)
    return __ret__.apply(lambda __response__: GetEndpointsResult(
        id=pulumi.get(__response__, 'id'),
        items=pulumi.get(__response__, 'items'),
        page_size=pulumi.get(__response__, 'page_size'),
        parent=pulumi.get(__response__, 'parent')))
