# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataClassificationCatalogConfigResult',
    'AwaitableGetDataClassificationCatalogConfigResult',
    'get_data_classification_catalog_config',
    'get_data_classification_catalog_config_output',
]

@pulumi.output_type
class GetDataClassificationCatalogConfigResult:
    """
    A collection of values returned by getDataClassificationCatalogConfig.
    """
    def __init__(__self__, auto_tag_configs=None, id=None, included_schemas=None, name=None, provider_config=None):
        if auto_tag_configs and not isinstance(auto_tag_configs, list):
            raise TypeError("Expected argument 'auto_tag_configs' to be a list")
        pulumi.set(__self__, "auto_tag_configs", auto_tag_configs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if included_schemas and not isinstance(included_schemas, dict):
            raise TypeError("Expected argument 'included_schemas' to be a dict")
        pulumi.set(__self__, "included_schemas", included_schemas)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="autoTagConfigs")
    def auto_tag_configs(self) -> Sequence['outputs.GetDataClassificationCatalogConfigAutoTagConfigResult']:
        """
        (list of AutoTaggingConfig) - List of auto-tagging configurations for this catalog.
        Empty list means no auto-tagging is enabled
        """
        return pulumi.get(self, "auto_tag_configs")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includedSchemas")
    def included_schemas(self) -> 'outputs.GetDataClassificationCatalogConfigIncludedSchemasResult':
        """
        (CatalogConfigSchemaNames) - Schemas to include in the scan. Empty list is not supported as it results in a no-op
        scan. If `included_schemas` is not set, all schemas are scanned
        """
        return pulumi.get(self, "included_schemas")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Resource name in the format: catalogs/{catalog_name}/config
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetDataClassificationCatalogConfigProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetDataClassificationCatalogConfigResult(GetDataClassificationCatalogConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataClassificationCatalogConfigResult(
            auto_tag_configs=self.auto_tag_configs,
            id=self.id,
            included_schemas=self.included_schemas,
            name=self.name,
            provider_config=self.provider_config)


def get_data_classification_catalog_config(name: Optional[_builtins.str] = None,
                                           provider_config: Optional[Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict']] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataClassificationCatalogConfigResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch the Data Classification configuration for a Unity Catalog catalog.

    To read the Data Classification configuration, you must have browse permissions on the catalog.

    > **Note** This data source can only be used with a workspace-level provider.

    ## Example Usage

    To get the Data Classification configuration for a catalog:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    prod = databricks.get_catalog(name="prod_catalog")
    prod_config = databricks.get_data_classification_catalog_config(name=f"catalogs/{prod.name}/config")
    pulumi.export("autoTagConfigs", prod_config.auto_tag_configs)
    ```


    :param _builtins.str name: Resource name in the format: catalogs/{catalog_name}/config
    :param Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDataClassificationCatalogConfig:getDataClassificationCatalogConfig', __args__, opts=opts, typ=GetDataClassificationCatalogConfigResult).value

    return AwaitableGetDataClassificationCatalogConfigResult(
        auto_tag_configs=pulumi.get(__ret__, 'auto_tag_configs'),
        id=pulumi.get(__ret__, 'id'),
        included_schemas=pulumi.get(__ret__, 'included_schemas'),
        name=pulumi.get(__ret__, 'name'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_data_classification_catalog_config_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                                  provider_config: Optional[pulumi.Input[Optional[Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict']]]] = None,
                                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDataClassificationCatalogConfigResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch the Data Classification configuration for a Unity Catalog catalog.

    To read the Data Classification configuration, you must have browse permissions on the catalog.

    > **Note** This data source can only be used with a workspace-level provider.

    ## Example Usage

    To get the Data Classification configuration for a catalog:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    prod = databricks.get_catalog(name="prod_catalog")
    prod_config = databricks.get_data_classification_catalog_config(name=f"catalogs/{prod.name}/config")
    pulumi.export("autoTagConfigs", prod_config.auto_tag_configs)
    ```


    :param _builtins.str name: Resource name in the format: catalogs/{catalog_name}/config
    :param Union['GetDataClassificationCatalogConfigProviderConfigArgs', 'GetDataClassificationCatalogConfigProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDataClassificationCatalogConfig:getDataClassificationCatalogConfig', __args__, opts=opts, typ=GetDataClassificationCatalogConfigResult)
    return __ret__.apply(lambda __response__: GetDataClassificationCatalogConfigResult(
        auto_tag_configs=pulumi.get(__response__, 'auto_tag_configs'),
        id=pulumi.get(__response__, 'id'),
        included_schemas=pulumi.get(__response__, 'included_schemas'),
        name=pulumi.get(__response__, 'name'),
        provider_config=pulumi.get(__response__, 'provider_config')))
