# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkspaceSettingV2Args', 'WorkspaceSettingV2']

@pulumi.input_type
class WorkspaceSettingV2Args:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']] = None,
                 boolean_val: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']] = None,
                 effective_personal_compute: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']] = None,
                 integer_val: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']] = None,
                 provider_config: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']] = None,
                 restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']] = None,
                 string_val: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']] = None):
        """
        The set of arguments for constructing a WorkspaceSettingV2 resource.
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs'] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs'] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input['WorkspaceSettingV2BooleanValArgs'] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs'] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs'] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs'] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs'] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs'] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input['WorkspaceSettingV2IntegerValArgs'] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input['WorkspaceSettingV2PersonalComputeArgs'] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input['WorkspaceSettingV2ProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs'] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input['WorkspaceSettingV2StringValArgs'] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        if aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_access_policy", aibi_dashboard_embedding_access_policy)
        if aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "automatic_cluster_update_workspace", automatic_cluster_update_workspace)
        if boolean_val is not None:
            pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_access_policy", effective_aibi_dashboard_embedding_access_policy)
        if effective_aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_approved_domains", effective_aibi_dashboard_embedding_approved_domains)
        if effective_automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "effective_automatic_cluster_update_workspace", effective_automatic_cluster_update_workspace)
        if effective_personal_compute is not None:
            pulumi.set(__self__, "effective_personal_compute", effective_personal_compute)
        if effective_restrict_workspace_admins is not None:
            pulumi.set(__self__, "effective_restrict_workspace_admins", effective_restrict_workspace_admins)
        if integer_val is not None:
            pulumi.set(__self__, "integer_val", integer_val)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if personal_compute is not None:
            pulumi.set(__self__, "personal_compute", personal_compute)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if restrict_workspace_admins is not None:
            pulumi.set(__self__, "restrict_workspace_admins", restrict_workspace_admins)
        if string_val is not None:
            pulumi.set(__self__, "string_val", string_val)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @aibi_dashboard_embedding_access_policy.setter
    def aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]:
        """
        Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @automatic_cluster_update_workspace.setter
    def automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]:
        """
        Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        """
        return pulumi.get(self, "boolean_val")

    @boolean_val.setter
    def boolean_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]):
        pulumi.set(self, "boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @effective_aibi_dashboard_embedding_access_policy.setter
    def effective_aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @effective_aibi_dashboard_embedding_approved_domains.setter
    def effective_aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]:
        """
        Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @effective_automatic_cluster_update_workspace.setter
    def effective_automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "effective_automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]:
        """
        Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        """
        return pulumi.get(self, "effective_personal_compute")

    @effective_personal_compute.setter
    def effective_personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]):
        pulumi.set(self, "effective_personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]:
        """
        Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @effective_restrict_workspace_admins.setter
    def effective_restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "effective_restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]:
        """
        Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        """
        return pulumi.get(self, "integer_val")

    @integer_val.setter
    def integer_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]):
        pulumi.set(self, "integer_val", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]:
        """
        Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        """
        return pulumi.get(self, "personal_compute")

    @personal_compute.setter
    def personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]):
        pulumi.set(self, "personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]:
        """
        Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @restrict_workspace_admins.setter
    def restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]:
        """
        Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        return pulumi.get(self, "string_val")

    @string_val.setter
    def string_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]):
        pulumi.set(self, "string_val", value)


@pulumi.input_type
class _WorkspaceSettingV2State:
    def __init__(__self__, *,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']] = None,
                 boolean_val: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']] = None,
                 effective_boolean_val: Optional[pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs']] = None,
                 effective_integer_val: Optional[pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs']] = None,
                 effective_personal_compute: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']] = None,
                 effective_string_val: Optional[pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs']] = None,
                 integer_val: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']] = None,
                 provider_config: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']] = None,
                 restrict_workspace_admins: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']] = None,
                 string_val: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']] = None):
        """
        Input properties used for looking up and filtering WorkspaceSettingV2 resources.
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs'] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs'] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs'] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input['WorkspaceSettingV2BooleanValArgs'] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs'] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs'] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs'] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs'] effective_boolean_val: (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        :param pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs'] effective_integer_val: (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        :param pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs'] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs'] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs'] effective_string_val: (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        :param pulumi.Input['WorkspaceSettingV2IntegerValArgs'] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input['WorkspaceSettingV2PersonalComputeArgs'] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input['WorkspaceSettingV2ProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs'] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input['WorkspaceSettingV2StringValArgs'] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        if aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_access_policy", aibi_dashboard_embedding_access_policy)
        if aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "aibi_dashboard_embedding_approved_domains", aibi_dashboard_embedding_approved_domains)
        if automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "automatic_cluster_update_workspace", automatic_cluster_update_workspace)
        if boolean_val is not None:
            pulumi.set(__self__, "boolean_val", boolean_val)
        if effective_aibi_dashboard_embedding_access_policy is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_access_policy", effective_aibi_dashboard_embedding_access_policy)
        if effective_aibi_dashboard_embedding_approved_domains is not None:
            pulumi.set(__self__, "effective_aibi_dashboard_embedding_approved_domains", effective_aibi_dashboard_embedding_approved_domains)
        if effective_automatic_cluster_update_workspace is not None:
            pulumi.set(__self__, "effective_automatic_cluster_update_workspace", effective_automatic_cluster_update_workspace)
        if effective_boolean_val is not None:
            pulumi.set(__self__, "effective_boolean_val", effective_boolean_val)
        if effective_integer_val is not None:
            pulumi.set(__self__, "effective_integer_val", effective_integer_val)
        if effective_personal_compute is not None:
            pulumi.set(__self__, "effective_personal_compute", effective_personal_compute)
        if effective_restrict_workspace_admins is not None:
            pulumi.set(__self__, "effective_restrict_workspace_admins", effective_restrict_workspace_admins)
        if effective_string_val is not None:
            pulumi.set(__self__, "effective_string_val", effective_string_val)
        if integer_val is not None:
            pulumi.set(__self__, "integer_val", integer_val)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if personal_compute is not None:
            pulumi.set(__self__, "personal_compute", personal_compute)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if restrict_workspace_admins is not None:
            pulumi.set(__self__, "restrict_workspace_admins", restrict_workspace_admins)
        if string_val is not None:
            pulumi.set(__self__, "string_val", string_val)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @aibi_dashboard_embedding_access_policy.setter
    def aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @aibi_dashboard_embedding_approved_domains.setter
    def aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]:
        """
        Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @automatic_cluster_update_workspace.setter
    def automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]:
        """
        Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        """
        return pulumi.get(self, "boolean_val")

    @boolean_val.setter
    def boolean_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2BooleanValArgs']]):
        pulumi.set(self, "boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @effective_aibi_dashboard_embedding_access_policy.setter
    def effective_aibi_dashboard_embedding_access_policy(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_access_policy", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]:
        """
        Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @effective_aibi_dashboard_embedding_approved_domains.setter
    def effective_aibi_dashboard_embedding_approved_domains(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs']]):
        pulumi.set(self, "effective_aibi_dashboard_embedding_approved_domains", value)

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]:
        """
        Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @effective_automatic_cluster_update_workspace.setter
    def effective_automatic_cluster_update_workspace(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs']]):
        pulumi.set(self, "effective_automatic_cluster_update_workspace", value)

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs']]:
        """
        (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        """
        return pulumi.get(self, "effective_boolean_val")

    @effective_boolean_val.setter
    def effective_boolean_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveBooleanValArgs']]):
        pulumi.set(self, "effective_boolean_val", value)

    @_builtins.property
    @pulumi.getter(name="effectiveIntegerVal")
    def effective_integer_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs']]:
        """
        (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        """
        return pulumi.get(self, "effective_integer_val")

    @effective_integer_val.setter
    def effective_integer_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveIntegerValArgs']]):
        pulumi.set(self, "effective_integer_val", value)

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]:
        """
        Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        """
        return pulumi.get(self, "effective_personal_compute")

    @effective_personal_compute.setter
    def effective_personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectivePersonalComputeArgs']]):
        pulumi.set(self, "effective_personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]:
        """
        Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @effective_restrict_workspace_admins.setter
    def effective_restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "effective_restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs']]:
        """
        (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        """
        return pulumi.get(self, "effective_string_val")

    @effective_string_val.setter
    def effective_string_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2EffectiveStringValArgs']]):
        pulumi.set(self, "effective_string_val", value)

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]:
        """
        Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        """
        return pulumi.get(self, "integer_val")

    @integer_val.setter
    def integer_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2IntegerValArgs']]):
        pulumi.set(self, "integer_val", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]:
        """
        Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        """
        return pulumi.get(self, "personal_compute")

    @personal_compute.setter
    def personal_compute(self, value: Optional[pulumi.Input['WorkspaceSettingV2PersonalComputeArgs']]):
        pulumi.set(self, "personal_compute", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['WorkspaceSettingV2ProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]:
        """
        Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @restrict_workspace_admins.setter
    def restrict_workspace_admins(self, value: Optional[pulumi.Input['WorkspaceSettingV2RestrictWorkspaceAdminsArgs']]):
        pulumi.set(self, "restrict_workspace_admins", value)

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]:
        """
        Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        return pulumi.get(self, "string_val")

    @string_val.setter
    def string_val(self, value: Optional[pulumi.Input['WorkspaceSettingV2StringValArgs']]):
        pulumi.set(self, "string_val", value)


@pulumi.type_token("databricks:index/workspaceSettingV2:WorkspaceSettingV2")
class WorkspaceSettingV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 effective_personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']]] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']]] = None,
                 integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']]] = None,
                 provider_config: Optional[pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']]] = None,
                 restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']]] = None,
                 string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Setting is a configurable value or control that determines how a feature or behavior works within the databricks platform.

        [//]: # (todo: add public link to metadata api after production doc link available)
        See settings-metadata api for list of settings that can be modified using this resource.

        ## Example Usage

        Getting a workspace level setting:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.WorkspaceSettingV2("this",
            name="llm_proxy_partner_powered",
            boolean_val={
                "value": False,
            })
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[WorkspaceSettingV2Args] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        Setting is a configurable value or control that determines how a feature or behavior works within the databricks platform.

        [//]: # (todo: add public link to metadata api after production doc link available)
        See settings-metadata api for list of settings that can be modified using this resource.

        ## Example Usage

        Getting a workspace level setting:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.WorkspaceSettingV2("this",
            name="llm_proxy_partner_powered",
            boolean_val={
                "value": False,
            })
        ```

        :param str resource_name: The name of the resource.
        :param WorkspaceSettingV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkspaceSettingV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
                 effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
                 effective_automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']]] = None,
                 effective_personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']]] = None,
                 effective_restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']]] = None,
                 integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']]] = None,
                 provider_config: Optional[pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']]] = None,
                 restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']]] = None,
                 string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkspaceSettingV2Args.__new__(WorkspaceSettingV2Args)

            __props__.__dict__["aibi_dashboard_embedding_access_policy"] = aibi_dashboard_embedding_access_policy
            __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
            __props__.__dict__["automatic_cluster_update_workspace"] = automatic_cluster_update_workspace
            __props__.__dict__["boolean_val"] = boolean_val
            __props__.__dict__["effective_aibi_dashboard_embedding_access_policy"] = effective_aibi_dashboard_embedding_access_policy
            __props__.__dict__["effective_aibi_dashboard_embedding_approved_domains"] = effective_aibi_dashboard_embedding_approved_domains
            __props__.__dict__["effective_automatic_cluster_update_workspace"] = effective_automatic_cluster_update_workspace
            __props__.__dict__["effective_personal_compute"] = effective_personal_compute
            __props__.__dict__["effective_restrict_workspace_admins"] = effective_restrict_workspace_admins
            __props__.__dict__["integer_val"] = integer_val
            __props__.__dict__["name"] = name
            __props__.__dict__["personal_compute"] = personal_compute
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["restrict_workspace_admins"] = restrict_workspace_admins
            __props__.__dict__["string_val"] = string_val
            __props__.__dict__["effective_boolean_val"] = None
            __props__.__dict__["effective_integer_val"] = None
            __props__.__dict__["effective_string_val"] = None
        super(WorkspaceSettingV2, __self__).__init__(
            'databricks:index/workspaceSettingV2:WorkspaceSettingV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
            aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
            automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']]] = None,
            boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']]] = None,
            effective_aibi_dashboard_embedding_access_policy: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']]] = None,
            effective_aibi_dashboard_embedding_approved_domains: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']]] = None,
            effective_automatic_cluster_update_workspace: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']]] = None,
            effective_boolean_val: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveBooleanValArgs', 'WorkspaceSettingV2EffectiveBooleanValArgsDict']]] = None,
            effective_integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveIntegerValArgs', 'WorkspaceSettingV2EffectiveIntegerValArgsDict']]] = None,
            effective_personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']]] = None,
            effective_restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']]] = None,
            effective_string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2EffectiveStringValArgs', 'WorkspaceSettingV2EffectiveStringValArgsDict']]] = None,
            integer_val: Optional[pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            personal_compute: Optional[pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']]] = None,
            provider_config: Optional[pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']]] = None,
            restrict_workspace_admins: Optional[pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']]] = None,
            string_val: Optional[pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']]] = None) -> 'WorkspaceSettingV2':
        """
        Get an existing WorkspaceSettingV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicyArgsDict']] aibi_dashboard_embedding_access_policy: Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomainsArgsDict']] aibi_dashboard_embedding_approved_domains: Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2AutomaticClusterUpdateWorkspaceArgsDict']] automatic_cluster_update_workspace: Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2BooleanValArgs', 'WorkspaceSettingV2BooleanValArgsDict']] boolean_val: Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicyArgsDict']] effective_aibi_dashboard_embedding_access_policy: Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgs', 'WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomainsArgsDict']] effective_aibi_dashboard_embedding_approved_domains: Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgs', 'WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspaceArgsDict']] effective_automatic_cluster_update_workspace: Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveBooleanValArgs', 'WorkspaceSettingV2EffectiveBooleanValArgsDict']] effective_boolean_val: (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveIntegerValArgs', 'WorkspaceSettingV2EffectiveIntegerValArgsDict']] effective_integer_val: (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        :param pulumi.Input[Union['WorkspaceSettingV2EffectivePersonalComputeArgs', 'WorkspaceSettingV2EffectivePersonalComputeArgsDict']] effective_personal_compute: Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2EffectiveRestrictWorkspaceAdminsArgsDict']] effective_restrict_workspace_admins: Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        :param pulumi.Input[Union['WorkspaceSettingV2EffectiveStringValArgs', 'WorkspaceSettingV2EffectiveStringValArgsDict']] effective_string_val: (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        :param pulumi.Input[Union['WorkspaceSettingV2IntegerValArgs', 'WorkspaceSettingV2IntegerValArgsDict']] integer_val: Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        :param pulumi.Input[_builtins.str] name: Name of the setting
        :param pulumi.Input[Union['WorkspaceSettingV2PersonalComputeArgs', 'WorkspaceSettingV2PersonalComputeArgsDict']] personal_compute: Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2ProviderConfigArgs', 'WorkspaceSettingV2ProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[Union['WorkspaceSettingV2RestrictWorkspaceAdminsArgs', 'WorkspaceSettingV2RestrictWorkspaceAdminsArgsDict']] restrict_workspace_admins: Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        :param pulumi.Input[Union['WorkspaceSettingV2StringValArgs', 'WorkspaceSettingV2StringValArgsDict']] string_val: Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkspaceSettingV2State.__new__(_WorkspaceSettingV2State)

        __props__.__dict__["aibi_dashboard_embedding_access_policy"] = aibi_dashboard_embedding_access_policy
        __props__.__dict__["aibi_dashboard_embedding_approved_domains"] = aibi_dashboard_embedding_approved_domains
        __props__.__dict__["automatic_cluster_update_workspace"] = automatic_cluster_update_workspace
        __props__.__dict__["boolean_val"] = boolean_val
        __props__.__dict__["effective_aibi_dashboard_embedding_access_policy"] = effective_aibi_dashboard_embedding_access_policy
        __props__.__dict__["effective_aibi_dashboard_embedding_approved_domains"] = effective_aibi_dashboard_embedding_approved_domains
        __props__.__dict__["effective_automatic_cluster_update_workspace"] = effective_automatic_cluster_update_workspace
        __props__.__dict__["effective_boolean_val"] = effective_boolean_val
        __props__.__dict__["effective_integer_val"] = effective_integer_val
        __props__.__dict__["effective_personal_compute"] = effective_personal_compute
        __props__.__dict__["effective_restrict_workspace_admins"] = effective_restrict_workspace_admins
        __props__.__dict__["effective_string_val"] = effective_string_val
        __props__.__dict__["integer_val"] = integer_val
        __props__.__dict__["name"] = name
        __props__.__dict__["personal_compute"] = personal_compute
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["restrict_workspace_admins"] = restrict_workspace_admins
        __props__.__dict__["string_val"] = string_val
        return WorkspaceSettingV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingAccessPolicy")
    def aibi_dashboard_embedding_access_policy(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2AibiDashboardEmbeddingAccessPolicy']]:
        """
        Setting value for aibi_dashboard_embedding_access_policy setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_access_policy for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="aibiDashboardEmbeddingApprovedDomains")
    def aibi_dashboard_embedding_approved_domains(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2AibiDashboardEmbeddingApprovedDomains']]:
        """
        Setting value for aibi_dashboard_embedding_approved_domains setting. This is the setting value set by consumers, check effective_aibi_dashboard_embedding_approved_domains for final setting value
        """
        return pulumi.get(self, "aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="automaticClusterUpdateWorkspace")
    def automatic_cluster_update_workspace(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2AutomaticClusterUpdateWorkspace']]:
        """
        Setting value for automatic_cluster_update_workspace setting. This is the setting value set by consumers, check effective_automatic_cluster_update_workspace for final setting value
        """
        return pulumi.get(self, "automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="booleanVal")
    def boolean_val(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2BooleanVal']]:
        """
        Setting value for boolean type setting. This is the setting value set by consumers, check effective_boolean_val for final setting value
        """
        return pulumi.get(self, "boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingAccessPolicy")
    def effective_aibi_dashboard_embedding_access_policy(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveAibiDashboardEmbeddingAccessPolicy']]:
        """
        Effective setting value for aibi_dashboard_embedding_access_policy setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_access_policy
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_access_policy")

    @_builtins.property
    @pulumi.getter(name="effectiveAibiDashboardEmbeddingApprovedDomains")
    def effective_aibi_dashboard_embedding_approved_domains(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveAibiDashboardEmbeddingApprovedDomains']]:
        """
        Effective setting value for aibi_dashboard_embedding_approved_domains setting. This is the final effective value of setting. To set a value use aibi_dashboard_embedding_approved_domains
        """
        return pulumi.get(self, "effective_aibi_dashboard_embedding_approved_domains")

    @_builtins.property
    @pulumi.getter(name="effectiveAutomaticClusterUpdateWorkspace")
    def effective_automatic_cluster_update_workspace(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveAutomaticClusterUpdateWorkspace']]:
        """
        Effective setting value for automatic_cluster_update_workspace setting. This is the final effective value of setting. To set a value use automatic_cluster_update_workspace
        """
        return pulumi.get(self, "effective_automatic_cluster_update_workspace")

    @_builtins.property
    @pulumi.getter(name="effectiveBooleanVal")
    def effective_boolean_val(self) -> pulumi.Output['outputs.WorkspaceSettingV2EffectiveBooleanVal']:
        """
        (BooleanMessage) - Effective setting value for boolean type setting. This is the final effective value of setting. To set a value use boolean_val
        """
        return pulumi.get(self, "effective_boolean_val")

    @_builtins.property
    @pulumi.getter(name="effectiveIntegerVal")
    def effective_integer_val(self) -> pulumi.Output['outputs.WorkspaceSettingV2EffectiveIntegerVal']:
        """
        (IntegerMessage) - Effective setting value for integer type setting. This is the final effective value of setting. To set a value use integer_val
        """
        return pulumi.get(self, "effective_integer_val")

    @_builtins.property
    @pulumi.getter(name="effectivePersonalCompute")
    def effective_personal_compute(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectivePersonalCompute']]:
        """
        Effective setting value for personal_compute setting. This is the final effective value of setting. To set a value use personal_compute
        """
        return pulumi.get(self, "effective_personal_compute")

    @_builtins.property
    @pulumi.getter(name="effectiveRestrictWorkspaceAdmins")
    def effective_restrict_workspace_admins(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2EffectiveRestrictWorkspaceAdmins']]:
        """
        Effective setting value for restrict_workspace_admins setting. This is the final effective value of setting. To set a value use restrict_workspace_admins
        """
        return pulumi.get(self, "effective_restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="effectiveStringVal")
    def effective_string_val(self) -> pulumi.Output['outputs.WorkspaceSettingV2EffectiveStringVal']:
        """
        (StringMessage) - Effective setting value for string type setting. This is the final effective value of setting. To set a value use string_val
        """
        return pulumi.get(self, "effective_string_val")

    @_builtins.property
    @pulumi.getter(name="integerVal")
    def integer_val(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2IntegerVal']]:
        """
        Setting value for integer type setting. This is the setting value set by consumers, check effective_integer_val for final setting value
        """
        return pulumi.get(self, "integer_val")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the setting
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="personalCompute")
    def personal_compute(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2PersonalCompute']]:
        """
        Setting value for personal_compute setting. This is the setting value set by consumers, check effective_personal_compute for final setting value
        """
        return pulumi.get(self, "personal_compute")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2ProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="restrictWorkspaceAdmins")
    def restrict_workspace_admins(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2RestrictWorkspaceAdmins']]:
        """
        Setting value for restrict_workspace_admins setting. This is the setting value set by consumers, check effective_restrict_workspace_admins for final setting value
        """
        return pulumi.get(self, "restrict_workspace_admins")

    @_builtins.property
    @pulumi.getter(name="stringVal")
    def string_val(self) -> pulumi.Output[Optional['outputs.WorkspaceSettingV2StringVal']]:
        """
        Setting value for string type setting. This is the setting value set by consumers, check effective_string_val for final setting value
        """
        return pulumi.get(self, "string_val")

