# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDataQualityMonitorsResult',
    'AwaitableGetDataQualityMonitorsResult',
    'get_data_quality_monitors',
    'get_data_quality_monitors_output',
]

@pulumi.output_type
class GetDataQualityMonitorsResult:
    """
    A collection of values returned by getDataQualityMonitors.
    """
    def __init__(__self__, id=None, monitors=None, page_size=None, provider_config=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if monitors and not isinstance(monitors, list):
            raise TypeError("Expected argument 'monitors' to be a list")
        pulumi.set(__self__, "monitors", monitors)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def monitors(self) -> Sequence['outputs.GetDataQualityMonitorsMonitorResult']:
        return pulumi.get(self, "monitors")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetDataQualityMonitorsProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetDataQualityMonitorsResult(GetDataQualityMonitorsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDataQualityMonitorsResult(
            id=self.id,
            monitors=self.monitors,
            page_size=self.page_size,
            provider_config=self.provider_config)


def get_data_quality_monitors(page_size: Optional[_builtins.int] = None,
                              provider_config: Optional[Union['GetDataQualityMonitorsProviderConfigArgs', 'GetDataQualityMonitorsProviderConfigArgsDict']] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDataQualityMonitorsResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch the list of data quality monitors.

    For the `table` `object_type`, the caller must either:
    1. be an owner of the table's parent catalog
    2. have **USE_CATALOG** on the table's parent catalog and be an owner of the table's parent schema.
    3. have the following permissions:
        - **USE_CATALOG** on the table's parent catalog
        - **USE_SCHEMA** on the table's parent schema
        - **SELECT** privilege on the table.

    > **Note** This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting a list of all data quality monitors:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_data_quality_monitors()
    ```


    :param Union['GetDataQualityMonitorsProviderConfigArgs', 'GetDataQualityMonitorsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDataQualityMonitors:getDataQualityMonitors', __args__, opts=opts, typ=GetDataQualityMonitorsResult).value

    return AwaitableGetDataQualityMonitorsResult(
        id=pulumi.get(__ret__, 'id'),
        monitors=pulumi.get(__ret__, 'monitors'),
        page_size=pulumi.get(__ret__, 'page_size'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_data_quality_monitors_output(page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                     provider_config: Optional[pulumi.Input[Optional[Union['GetDataQualityMonitorsProviderConfigArgs', 'GetDataQualityMonitorsProviderConfigArgsDict']]]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDataQualityMonitorsResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to fetch the list of data quality monitors.

    For the `table` `object_type`, the caller must either:
    1. be an owner of the table's parent catalog
    2. have **USE_CATALOG** on the table's parent catalog and be an owner of the table's parent schema.
    3. have the following permissions:
        - **USE_CATALOG** on the table's parent catalog
        - **USE_SCHEMA** on the table's parent schema
        - **SELECT** privilege on the table.

    > **Note** This data source can only be used with a workspace-level provider!

    ## Example Usage

    Getting a list of all data quality monitors:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_data_quality_monitors()
    ```


    :param Union['GetDataQualityMonitorsProviderConfigArgs', 'GetDataQualityMonitorsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDataQualityMonitors:getDataQualityMonitors', __args__, opts=opts, typ=GetDataQualityMonitorsResult)
    return __ret__.apply(lambda __response__: GetDataQualityMonitorsResult(
        id=pulumi.get(__response__, 'id'),
        monitors=pulumi.get(__response__, 'monitors'),
        page_size=pulumi.get(__response__, 'page_size'),
        provider_config=pulumi.get(__response__, 'provider_config')))
