# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetFeatureEngineeringFeatureResult',
    'AwaitableGetFeatureEngineeringFeatureResult',
    'get_feature_engineering_feature',
    'get_feature_engineering_feature_output',
]

@pulumi.output_type
class GetFeatureEngineeringFeatureResult:
    """
    A collection of values returned by getFeatureEngineeringFeature.
    """
    def __init__(__self__, description=None, filter_condition=None, full_name=None, function=None, id=None, inputs=None, lineage_context=None, provider_config=None, source=None, time_window=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if filter_condition and not isinstance(filter_condition, str):
            raise TypeError("Expected argument 'filter_condition' to be a str")
        pulumi.set(__self__, "filter_condition", filter_condition)
        if full_name and not isinstance(full_name, str):
            raise TypeError("Expected argument 'full_name' to be a str")
        pulumi.set(__self__, "full_name", full_name)
        if function and not isinstance(function, dict):
            raise TypeError("Expected argument 'function' to be a dict")
        pulumi.set(__self__, "function", function)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if inputs and not isinstance(inputs, list):
            raise TypeError("Expected argument 'inputs' to be a list")
        pulumi.set(__self__, "inputs", inputs)
        if lineage_context and not isinstance(lineage_context, dict):
            raise TypeError("Expected argument 'lineage_context' to be a dict")
        pulumi.set(__self__, "lineage_context", lineage_context)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)
        if source and not isinstance(source, dict):
            raise TypeError("Expected argument 'source' to be a dict")
        pulumi.set(__self__, "source", source)
        if time_window and not isinstance(time_window, dict):
            raise TypeError("Expected argument 'time_window' to be a dict")
        pulumi.set(__self__, "time_window", time_window)

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (string) - The description of the feature
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="filterCondition")
    def filter_condition(self) -> _builtins.str:
        """
        (string) - Single WHERE clause to filter delta table before applying transformations. Will be row-wise evaluated, so should only include conditionals and projections
        """
        return pulumi.get(self, "filter_condition")

    @_builtins.property
    @pulumi.getter(name="fullName")
    def full_name(self) -> _builtins.str:
        """
        (string) - The full three-part (catalog, schema, table) name of the Delta table
        """
        return pulumi.get(self, "full_name")

    @_builtins.property
    @pulumi.getter
    def function(self) -> 'outputs.GetFeatureEngineeringFeatureFunctionResult':
        """
        (Function) - The function by which the feature is computed
        """
        return pulumi.get(self, "function")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> Sequence[_builtins.str]:
        """
        (list of string, deprecated) - Deprecated: Use AggregationFunction.inputs instead. Kept for backwards compatibility.
        The input columns from which the feature is computed
        """
        return pulumi.get(self, "inputs")

    @_builtins.property
    @pulumi.getter(name="lineageContext")
    def lineage_context(self) -> 'outputs.GetFeatureEngineeringFeatureLineageContextResult':
        """
        (LineageContext) - Lineage context information for this feature.
        WARNING: This field is primarily intended for internal use by Databricks systems and
        is automatically populated when features are created through Databricks notebooks or jobs.
        Users should not manually set this field as incorrect values may lead to inaccurate lineage tracking or unexpected behavior.
        This field will be set by feature-engineering client and should be left unset by SDK and terraform users
        """
        return pulumi.get(self, "lineage_context")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetFeatureEngineeringFeatureProviderConfigResult']:
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter
    def source(self) -> 'outputs.GetFeatureEngineeringFeatureSourceResult':
        """
        (DataSource) - The data source of the feature
        """
        return pulumi.get(self, "source")

    @_builtins.property
    @pulumi.getter(name="timeWindow")
    def time_window(self) -> 'outputs.GetFeatureEngineeringFeatureTimeWindowResult':
        """
        (TimeWindow, deprecated) - Deprecated: Use Function.aggregation_function.time_window instead. Kept for backwards compatibility.
        The time window in which the feature is computed
        """
        return pulumi.get(self, "time_window")


class AwaitableGetFeatureEngineeringFeatureResult(GetFeatureEngineeringFeatureResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFeatureEngineeringFeatureResult(
            description=self.description,
            filter_condition=self.filter_condition,
            full_name=self.full_name,
            function=self.function,
            id=self.id,
            inputs=self.inputs,
            lineage_context=self.lineage_context,
            provider_config=self.provider_config,
            source=self.source,
            time_window=self.time_window)


def get_feature_engineering_feature(full_name: Optional[_builtins.str] = None,
                                    provider_config: Optional[Union['GetFeatureEngineeringFeatureProviderConfigArgs', 'GetFeatureEngineeringFeatureProviderConfigArgsDict']] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFeatureEngineeringFeatureResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str full_name: The full three-part name (catalog, schema, name) of the feature
    :param Union['GetFeatureEngineeringFeatureProviderConfigArgs', 'GetFeatureEngineeringFeatureProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['fullName'] = full_name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getFeatureEngineeringFeature:getFeatureEngineeringFeature', __args__, opts=opts, typ=GetFeatureEngineeringFeatureResult).value

    return AwaitableGetFeatureEngineeringFeatureResult(
        description=pulumi.get(__ret__, 'description'),
        filter_condition=pulumi.get(__ret__, 'filter_condition'),
        full_name=pulumi.get(__ret__, 'full_name'),
        function=pulumi.get(__ret__, 'function'),
        id=pulumi.get(__ret__, 'id'),
        inputs=pulumi.get(__ret__, 'inputs'),
        lineage_context=pulumi.get(__ret__, 'lineage_context'),
        provider_config=pulumi.get(__ret__, 'provider_config'),
        source=pulumi.get(__ret__, 'source'),
        time_window=pulumi.get(__ret__, 'time_window'))
def get_feature_engineering_feature_output(full_name: Optional[pulumi.Input[_builtins.str]] = None,
                                           provider_config: Optional[pulumi.Input[Optional[Union['GetFeatureEngineeringFeatureProviderConfigArgs', 'GetFeatureEngineeringFeatureProviderConfigArgsDict']]]] = None,
                                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFeatureEngineeringFeatureResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str full_name: The full three-part name (catalog, schema, name) of the feature
    :param Union['GetFeatureEngineeringFeatureProviderConfigArgs', 'GetFeatureEngineeringFeatureProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['fullName'] = full_name
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getFeatureEngineeringFeature:getFeatureEngineeringFeature', __args__, opts=opts, typ=GetFeatureEngineeringFeatureResult)
    return __ret__.apply(lambda __response__: GetFeatureEngineeringFeatureResult(
        description=pulumi.get(__response__, 'description'),
        filter_condition=pulumi.get(__response__, 'filter_condition'),
        full_name=pulumi.get(__response__, 'full_name'),
        function=pulumi.get(__response__, 'function'),
        id=pulumi.get(__response__, 'id'),
        inputs=pulumi.get(__response__, 'inputs'),
        lineage_context=pulumi.get(__response__, 'lineage_context'),
        provider_config=pulumi.get(__response__, 'provider_config'),
        source=pulumi.get(__response__, 'source'),
        time_window=pulumi.get(__response__, 'time_window')))
