# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .access_control_rule_set import *
from .account_federation_policy import *
from .account_network_policy import *
from .account_setting_user_preference_v2 import *
from .account_setting_v2 import *
from .aibi_dashboard_embedding_access_policy_setting import *
from .aibi_dashboard_embedding_approved_domains_setting import *
from .alert import *
from .alert_v2 import *
from .app import *
from .app_space import *
from .apps_settings_custom_template import *
from .artifact_allowlist import *
from .automatic_cluster_update_workspace_setting import *
from .budget import *
from .budget_policy import *
from .catalog import *
from .catalog_workspace_binding import *
from .cluster import *
from .cluster_policy import *
from .compliance_security_profile_workspace_setting import *
from .connection import *
from .credential import *
from .custom_app_integration import *
from .dashboard import *
from .data_classification_catalog_config import *
from .data_quality_monitor import *
from .data_quality_refresh import *
from .database_database_catalog import *
from .database_instance import *
from .database_synced_database_table import *
from .dbfs_file import *
from .default_namespace_setting import *
from .directory import *
from .disable_legacy_access_setting import *
from .disable_legacy_dbfs_setting import *
from .disable_legacy_features_setting import *
from .endpoint import *
from .enhanced_security_monitoring_workspace_setting import *
from .entitlements import *
from .entity_tag_assignment import *
from .external_location import *
from .external_metadata import *
from .feature_engineering_feature import *
from .feature_engineering_kafka_config import *
from .feature_engineering_materialized_feature import *
from .file import *
from .get_account_federation_policies import *
from .get_account_federation_policy import *
from .get_account_network_policies import *
from .get_account_network_policy import *
from .get_account_setting_user_preference_v2 import *
from .get_account_setting_v2 import *
from .get_alert_v2 import *
from .get_alerts_v2 import *
from .get_app import *
from .get_app_space import *
from .get_app_spaces import *
from .get_apps import *
from .get_apps_settings_custom_template import *
from .get_apps_settings_custom_templates import *
from .get_aws_assume_role_policy import *
from .get_aws_bucket_policy import *
from .get_aws_cross_account_policy import *
from .get_aws_unity_catalog_assume_role_policy import *
from .get_aws_unity_catalog_policy import *
from .get_budget_policies import *
from .get_budget_policy import *
from .get_catalog import *
from .get_catalogs import *
from .get_cluster import *
from .get_cluster_policy import *
from .get_clusters import *
from .get_current_config import *
from .get_current_metastore import *
from .get_current_user import *
from .get_dashboards import *
from .get_data_classification_catalog_config import *
from .get_data_quality_monitor import *
from .get_data_quality_monitors import *
from .get_data_quality_refresh import *
from .get_data_quality_refreshes import *
from .get_database_database_catalog import *
from .get_database_database_catalogs import *
from .get_database_instance import *
from .get_database_instances import *
from .get_database_synced_database_table import *
from .get_database_synced_database_tables import *
from .get_dbfs_file import *
from .get_dbfs_file_paths import *
from .get_directory import *
from .get_endpoint import *
from .get_endpoints import *
from .get_entity_tag_assignment import *
from .get_entity_tag_assignments import *
from .get_external_location import *
from .get_external_locations import *
from .get_external_metadata import *
from .get_external_metadatas import *
from .get_feature_engineering_feature import *
from .get_feature_engineering_features import *
from .get_feature_engineering_kafka_config import *
from .get_feature_engineering_kafka_configs import *
from .get_feature_engineering_materialized_feature import *
from .get_feature_engineering_materialized_features import *
from .get_functions import *
from .get_group import *
from .get_instance_pool import *
from .get_instance_profiles import *
from .get_job import *
from .get_jobs import *
from .get_knowledge_assistant import *
from .get_knowledge_assistant_knowledge_source import *
from .get_knowledge_assistant_knowledge_sources import *
from .get_knowledge_assistants import *
from .get_materialized_features_feature_tag import *
from .get_materialized_features_feature_tags import *
from .get_metastore import *
from .get_metastores import *
from .get_mlflow_experiment import *
from .get_mlflow_model import *
from .get_mlflow_models import *
from .get_mws_credentials import *
from .get_mws_network_connectivity_config import *
from .get_mws_network_connectivity_configs import *
from .get_mws_workspaces import *
from .get_node_type import *
from .get_notebook import *
from .get_notebook_paths import *
from .get_notification_destinations import *
from .get_online_store import *
from .get_online_stores import *
from .get_pipelines import *
from .get_policy_info import *
from .get_policy_infos import *
from .get_postgres_branch import *
from .get_postgres_branches import *
from .get_postgres_database import *
from .get_postgres_databases import *
from .get_postgres_endpoint import *
from .get_postgres_endpoints import *
from .get_postgres_project import *
from .get_postgres_projects import *
from .get_quality_monitor_v2 import *
from .get_quality_monitors_v2 import *
from .get_registered_model import *
from .get_registered_model_versions import *
from .get_rfa_access_request_destinations import *
from .get_schema import *
from .get_schemas import *
from .get_service_principal import *
from .get_service_principal_federation_policies import *
from .get_service_principal_federation_policy import *
from .get_service_principals import *
from .get_serving_endpoints import *
from .get_share import *
from .get_shares import *
from .get_spark_version import *
from .get_sql_warehouse import *
from .get_sql_warehouses import *
from .get_storage_credential import *
from .get_storage_credentials import *
from .get_table import *
from .get_tables import *
from .get_tag_policies import *
from .get_tag_policy import *
from .get_user import *
from .get_users import *
from .get_views import *
from .get_volume import *
from .get_volumes import *
from .get_warehouses_default_warehouse_override import *
from .get_warehouses_default_warehouse_overrides import *
from .get_workspace_entity_tag_assignment import *
from .get_workspace_entity_tag_assignments import *
from .get_workspace_network_option import *
from .get_workspace_setting_v2 import *
from .get_zones import *
from .git_credential import *
from .global_init_script import *
from .grant import *
from .grants import *
from .group import *
from .group_instance_profile import *
from .group_member import *
from .group_role import *
from .instance_pool import *
from .instance_profile import *
from .ip_access_list import *
from .job import *
from .knowledge_assistant import *
from .knowledge_assistant_knowledge_source import *
from .lakehouse_monitor import *
from .library import *
from .materialized_features_feature_tag import *
from .metastore import *
from .metastore_assignment import *
from .metastore_data_access import *
from .metastore_provider import *
from .mlflow_experiment import *
from .mlflow_model import *
from .mlflow_webhook import *
from .model_serving import *
from .model_serving_provisioned_throughput import *
from .mount import *
from .mws_credentials import *
from .mws_customer_managed_keys import *
from .mws_log_delivery import *
from .mws_ncc_binding import *
from .mws_ncc_private_endpoint_rule import *
from .mws_network_connectivity_config import *
from .mws_networks import *
from .mws_permission_assignment import *
from .mws_private_access_settings import *
from .mws_storage_configurations import *
from .mws_vpc_endpoint import *
from .mws_workspaces import *
from .notebook import *
from .notification_destination import *
from .obo_token import *
from .online_store import *
from .online_table import *
from .permission_assignment import *
from .permissions import *
from .pipeline import *
from .policy_info import *
from .postgres_branch import *
from .postgres_database import *
from .postgres_endpoint import *
from .postgres_project import *
from .provider import *
from .quality_monitor import *
from .quality_monitor_v2 import *
from .query import *
from .recipient import *
from .registered_model import *
from .repo import *
from .restrict_workspace_admins_setting import *
from .rfa_access_request_destinations import *
from .schema import *
from .secret import *
from .secret_acl import *
from .secret_scope import *
from .service_principal import *
from .service_principal_federation_policy import *
from .service_principal_role import *
from .service_principal_secret import *
from .share import *
from .sql_alert import *
from .sql_dashboard import *
from .sql_endpoint import *
from .sql_global_config import *
from .sql_permissions import *
from .sql_query import *
from .sql_table import *
from .sql_visualization import *
from .sql_widget import *
from .storage_credential import *
from .system_schema import *
from .table import *
from .tag_policy import *
from .token import *
from .user import *
from .user_instance_profile import *
from .user_role import *
from .vector_search_endpoint import *
from .vector_search_index import *
from .volume import *
from .warehouses_default_warehouse_override import *
from .workspace_binding import *
from .workspace_conf import *
from .workspace_entity_tag_assignment import *
from .workspace_file import *
from .workspace_network_option import *
from .workspace_setting_v2 import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_databricks.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_databricks.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "databricks",
  "mod": "index/accessControlRuleSet",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accessControlRuleSet:AccessControlRuleSet": "AccessControlRuleSet"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountFederationPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountFederationPolicy:AccountFederationPolicy": "AccountFederationPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountNetworkPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountNetworkPolicy:AccountNetworkPolicy": "AccountNetworkPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountSettingUserPreferenceV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountSettingUserPreferenceV2:AccountSettingUserPreferenceV2": "AccountSettingUserPreferenceV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/accountSettingV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/accountSettingV2:AccountSettingV2": "AccountSettingV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/aibiDashboardEmbeddingAccessPolicySetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/aibiDashboardEmbeddingAccessPolicySetting:AibiDashboardEmbeddingAccessPolicySetting": "AibiDashboardEmbeddingAccessPolicySetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/aibiDashboardEmbeddingApprovedDomainsSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/aibiDashboardEmbeddingApprovedDomainsSetting:AibiDashboardEmbeddingApprovedDomainsSetting": "AibiDashboardEmbeddingApprovedDomainsSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/alert",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/alert:Alert": "Alert"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/alertV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/alertV2:AlertV2": "AlertV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/app",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/app:App": "App"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/appSpace",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/appSpace:AppSpace": "AppSpace"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/appsSettingsCustomTemplate",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/appsSettingsCustomTemplate:AppsSettingsCustomTemplate": "AppsSettingsCustomTemplate"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/artifactAllowlist",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/artifactAllowlist:ArtifactAllowlist": "ArtifactAllowlist"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/automaticClusterUpdateWorkspaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/automaticClusterUpdateWorkspaceSetting:AutomaticClusterUpdateWorkspaceSetting": "AutomaticClusterUpdateWorkspaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/budget",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/budget:Budget": "Budget"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/budgetPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/budgetPolicy:BudgetPolicy": "BudgetPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/catalog",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/catalog:Catalog": "Catalog"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/catalogWorkspaceBinding",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/catalogWorkspaceBinding:CatalogWorkspaceBinding": "CatalogWorkspaceBinding"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/cluster",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/clusterPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/clusterPolicy:ClusterPolicy": "ClusterPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/complianceSecurityProfileWorkspaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/complianceSecurityProfileWorkspaceSetting:ComplianceSecurityProfileWorkspaceSetting": "ComplianceSecurityProfileWorkspaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/connection",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/connection:Connection": "Connection"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/credential",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/credential:Credential": "Credential"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/customAppIntegration",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/customAppIntegration:CustomAppIntegration": "CustomAppIntegration"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dashboard",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dashboard:Dashboard": "Dashboard"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dataClassificationCatalogConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dataClassificationCatalogConfig:DataClassificationCatalogConfig": "DataClassificationCatalogConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dataQualityMonitor",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dataQualityMonitor:DataQualityMonitor": "DataQualityMonitor"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dataQualityRefresh",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dataQualityRefresh:DataQualityRefresh": "DataQualityRefresh"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/databaseDatabaseCatalog",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/databaseDatabaseCatalog:DatabaseDatabaseCatalog": "DatabaseDatabaseCatalog"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/databaseInstance",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/databaseSyncedDatabaseTable",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/databaseSyncedDatabaseTable:DatabaseSyncedDatabaseTable": "DatabaseSyncedDatabaseTable"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/dbfsFile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/dbfsFile:DbfsFile": "DbfsFile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/defaultNamespaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/defaultNamespaceSetting:DefaultNamespaceSetting": "DefaultNamespaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/directory",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/directory:Directory": "Directory"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/disableLegacyAccessSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/disableLegacyAccessSetting:DisableLegacyAccessSetting": "DisableLegacyAccessSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/disableLegacyDbfsSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/disableLegacyDbfsSetting:DisableLegacyDbfsSetting": "DisableLegacyDbfsSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/disableLegacyFeaturesSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/disableLegacyFeaturesSetting:DisableLegacyFeaturesSetting": "DisableLegacyFeaturesSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/endpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/enhancedSecurityMonitoringWorkspaceSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/enhancedSecurityMonitoringWorkspaceSetting:EnhancedSecurityMonitoringWorkspaceSetting": "EnhancedSecurityMonitoringWorkspaceSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/entitlements",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/entitlements:Entitlements": "Entitlements"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/entityTagAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/entityTagAssignment:EntityTagAssignment": "EntityTagAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/externalLocation",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/externalLocation:ExternalLocation": "ExternalLocation"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/externalMetadata",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/externalMetadata:ExternalMetadata": "ExternalMetadata"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/featureEngineeringFeature",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/featureEngineeringFeature:FeatureEngineeringFeature": "FeatureEngineeringFeature"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/featureEngineeringKafkaConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/featureEngineeringKafkaConfig:FeatureEngineeringKafkaConfig": "FeatureEngineeringKafkaConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/featureEngineeringMaterializedFeature",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/featureEngineeringMaterializedFeature:FeatureEngineeringMaterializedFeature": "FeatureEngineeringMaterializedFeature"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/file",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/file:File": "File"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/gitCredential",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/gitCredential:GitCredential": "GitCredential"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/globalInitScript",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/globalInitScript:GlobalInitScript": "GlobalInitScript"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/grant",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/grant:Grant": "Grant"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/grants",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/grants:Grants": "Grants"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/group",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/group:Group": "Group"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/groupInstanceProfile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/groupInstanceProfile:GroupInstanceProfile": "GroupInstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/groupMember",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/groupMember:GroupMember": "GroupMember"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/groupRole",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/groupRole:GroupRole": "GroupRole"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/instancePool",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/instancePool:InstancePool": "InstancePool"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/instanceProfile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/instanceProfile:InstanceProfile": "InstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/ipAccessList",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/ipAccessList:IpAccessList": "IpAccessList"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/job",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/job:Job": "Job"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/knowledgeAssistant",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/knowledgeAssistant:KnowledgeAssistant": "KnowledgeAssistant"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/knowledgeAssistantKnowledgeSource",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/knowledgeAssistantKnowledgeSource:KnowledgeAssistantKnowledgeSource": "KnowledgeAssistantKnowledgeSource"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/lakehouseMonitor",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/lakehouseMonitor:LakehouseMonitor": "LakehouseMonitor"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/library",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/library:Library": "Library"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/materializedFeaturesFeatureTag",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/materializedFeaturesFeatureTag:MaterializedFeaturesFeatureTag": "MaterializedFeaturesFeatureTag"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastore",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastore:Metastore": "Metastore"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastoreAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastoreAssignment:MetastoreAssignment": "MetastoreAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastoreDataAccess",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastoreDataAccess:MetastoreDataAccess": "MetastoreDataAccess"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/metastoreProvider",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/metastoreProvider:MetastoreProvider": "MetastoreProvider"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mlflowExperiment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mlflowExperiment:MlflowExperiment": "MlflowExperiment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mlflowModel",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mlflowModel:MlflowModel": "MlflowModel"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mlflowWebhook",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mlflowWebhook:MlflowWebhook": "MlflowWebhook"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/modelServing",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/modelServing:ModelServing": "ModelServing"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/modelServingProvisionedThroughput",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/modelServingProvisionedThroughput:ModelServingProvisionedThroughput": "ModelServingProvisionedThroughput"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mount",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mount:Mount": "Mount"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsCredentials",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsCredentials:MwsCredentials": "MwsCredentials"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsCustomerManagedKeys",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsCustomerManagedKeys:MwsCustomerManagedKeys": "MwsCustomerManagedKeys"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsLogDelivery",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsLogDelivery:MwsLogDelivery": "MwsLogDelivery"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNccBinding",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNccBinding:MwsNccBinding": "MwsNccBinding"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNccPrivateEndpointRule",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNccPrivateEndpointRule:MwsNccPrivateEndpointRule": "MwsNccPrivateEndpointRule"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNetworkConnectivityConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNetworkConnectivityConfig:MwsNetworkConnectivityConfig": "MwsNetworkConnectivityConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsNetworks",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsNetworks:MwsNetworks": "MwsNetworks"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsPermissionAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsPermissionAssignment:MwsPermissionAssignment": "MwsPermissionAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsPrivateAccessSettings",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsPrivateAccessSettings:MwsPrivateAccessSettings": "MwsPrivateAccessSettings"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsStorageConfigurations",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsStorageConfigurations:MwsStorageConfigurations": "MwsStorageConfigurations"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsVpcEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsVpcEndpoint:MwsVpcEndpoint": "MwsVpcEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/mwsWorkspaces",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/mwsWorkspaces:MwsWorkspaces": "MwsWorkspaces"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/notebook",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/notebook:Notebook": "Notebook"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/notificationDestination",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/notificationDestination:NotificationDestination": "NotificationDestination"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/oboToken",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/oboToken:OboToken": "OboToken"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/onlineStore",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/onlineStore:OnlineStore": "OnlineStore"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/onlineTable",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/onlineTable:OnlineTable": "OnlineTable"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/permissionAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/permissionAssignment:PermissionAssignment": "PermissionAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/permissions",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/permissions:Permissions": "Permissions"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/pipeline",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/pipeline:Pipeline": "Pipeline"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/policyInfo",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/policyInfo:PolicyInfo": "PolicyInfo"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresBranch",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresBranch:PostgresBranch": "PostgresBranch"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresDatabase",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresDatabase:PostgresDatabase": "PostgresDatabase"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresEndpoint:PostgresEndpoint": "PostgresEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/postgresProject",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/postgresProject:PostgresProject": "PostgresProject"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/qualityMonitor",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/qualityMonitor:QualityMonitor": "QualityMonitor"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/qualityMonitorV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/qualityMonitorV2:QualityMonitorV2": "QualityMonitorV2"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/query",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/query:Query": "Query"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/recipient",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/recipient:Recipient": "Recipient"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/registeredModel",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/registeredModel:RegisteredModel": "RegisteredModel"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/repo",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/repo:Repo": "Repo"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/restrictWorkspaceAdminsSetting",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/restrictWorkspaceAdminsSetting:RestrictWorkspaceAdminsSetting": "RestrictWorkspaceAdminsSetting"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/rfaAccessRequestDestinations",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/rfaAccessRequestDestinations:RfaAccessRequestDestinations": "RfaAccessRequestDestinations"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/schema",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/schema:Schema": "Schema"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/secret",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/secretAcl",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/secretAcl:SecretAcl": "SecretAcl"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/secretScope",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/secretScope:SecretScope": "SecretScope"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipal",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipal:ServicePrincipal": "ServicePrincipal"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipalFederationPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipalFederationPolicy:ServicePrincipalFederationPolicy": "ServicePrincipalFederationPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipalRole",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipalRole:ServicePrincipalRole": "ServicePrincipalRole"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/servicePrincipalSecret",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/servicePrincipalSecret:ServicePrincipalSecret": "ServicePrincipalSecret"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/share",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/share:Share": "Share"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlAlert",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlAlert:SqlAlert": "SqlAlert"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlDashboard",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlDashboard:SqlDashboard": "SqlDashboard"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlEndpoint:SqlEndpoint": "SqlEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlGlobalConfig",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlGlobalConfig:SqlGlobalConfig": "SqlGlobalConfig"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlPermissions",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlPermissions:SqlPermissions": "SqlPermissions"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlQuery",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlQuery:SqlQuery": "SqlQuery"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlTable",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlTable:SqlTable": "SqlTable"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlVisualization",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlVisualization:SqlVisualization": "SqlVisualization"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/sqlWidget",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/sqlWidget:SqlWidget": "SqlWidget"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/storageCredential",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/storageCredential:StorageCredential": "StorageCredential"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/systemSchema",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/systemSchema:SystemSchema": "SystemSchema"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/table",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/table:Table": "Table"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/tagPolicy",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/tagPolicy:TagPolicy": "TagPolicy"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/token",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/token:Token": "Token"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/user",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/user:User": "User"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/userInstanceProfile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/userInstanceProfile:UserInstanceProfile": "UserInstanceProfile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/userRole",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/userRole:UserRole": "UserRole"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/vectorSearchEndpoint",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/vectorSearchEndpoint:VectorSearchEndpoint": "VectorSearchEndpoint"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/vectorSearchIndex",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/vectorSearchIndex:VectorSearchIndex": "VectorSearchIndex"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/volume",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/warehousesDefaultWarehouseOverride",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/warehousesDefaultWarehouseOverride:WarehousesDefaultWarehouseOverride": "WarehousesDefaultWarehouseOverride"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceBinding",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceBinding:WorkspaceBinding": "WorkspaceBinding"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceConf",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceConf:WorkspaceConf": "WorkspaceConf"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceEntityTagAssignment",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceEntityTagAssignment:WorkspaceEntityTagAssignment": "WorkspaceEntityTagAssignment"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceFile",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceFile:WorkspaceFile": "WorkspaceFile"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceNetworkOption",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceNetworkOption:WorkspaceNetworkOption": "WorkspaceNetworkOption"
  }
 },
 {
  "pkg": "databricks",
  "mod": "index/workspaceSettingV2",
  "fqn": "pulumi_databricks",
  "classes": {
   "databricks:index/workspaceSettingV2:WorkspaceSettingV2": "WorkspaceSettingV2"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "databricks",
  "token": "pulumi:providers:databricks",
  "fqn": "pulumi_databricks",
  "class": "Provider"
 }
]
"""
)
