# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KnowledgeAssistantKnowledgeSourceArgs', 'KnowledgeAssistantKnowledgeSource']

@pulumi.input_type
class KnowledgeAssistantKnowledgeSourceArgs:
    def __init__(__self__, *,
                 description: pulumi.Input[_builtins.str],
                 display_name: pulumi.Input[_builtins.str],
                 parent: pulumi.Input[_builtins.str],
                 source_type: pulumi.Input[_builtins.str],
                 file_table: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']] = None,
                 files: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']] = None,
                 index: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']] = None,
                 provider_config: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a KnowledgeAssistantKnowledgeSource resource.
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        :param pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        """
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "parent", parent)
        pulumi.set(__self__, "source_type", source_type)
        if file_table is not None:
            pulumi.set(__self__, "file_table", file_table)
        if files is not None:
            pulumi.set(__self__, "files", files)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Input[_builtins.str]:
        """
        Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Input[_builtins.str]:
        """
        Parent resource where this source will be created.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_type", value)

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]:
        return pulumi.get(self, "file_table")

    @file_table.setter
    def file_table(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]):
        pulumi.set(self, "file_table", value)

    @_builtins.property
    @pulumi.getter
    def files(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]:
        return pulumi.get(self, "files")

    @files.setter
    def files(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]):
        pulumi.set(self, "files", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]:
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _KnowledgeAssistantKnowledgeSourceState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 file_table: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']] = None,
                 files: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']] = None,
                 index: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']] = None,
                 knowledge_cutoff_time: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']] = None,
                 source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering KnowledgeAssistantKnowledgeSource resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - Timestamp when this knowledge source was created
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] knowledge_cutoff_time: (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        :param pulumi.Input[_builtins.str] name: (string) - Full resource name:
               knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs'] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        :param pulumi.Input[_builtins.str] state: (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if file_table is not None:
            pulumi.set(__self__, "file_table", file_table)
        if files is not None:
            pulumi.set(__self__, "files", files)
        if index is not None:
            pulumi.set(__self__, "index", index)
        if knowledge_cutoff_time is not None:
            pulumi.set(__self__, "knowledge_cutoff_time", knowledge_cutoff_time)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parent is not None:
            pulumi.set(__self__, "parent", parent)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if source_type is not None:
            pulumi.set(__self__, "source_type", source_type)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Timestamp when this knowledge source was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]:
        return pulumi.get(self, "file_table")

    @file_table.setter
    def file_table(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFileTableArgs']]):
        pulumi.set(self, "file_table", value)

    @_builtins.property
    @pulumi.getter
    def files(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]:
        return pulumi.get(self, "files")

    @files.setter
    def files(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceFilesArgs']]):
        pulumi.set(self, "files", value)

    @_builtins.property
    @pulumi.getter
    def index(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]:
        return pulumi.get(self, "index")

    @index.setter
    def index(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceIndexArgs']]):
        pulumi.set(self, "index", value)

    @_builtins.property
    @pulumi.getter(name="knowledgeCutoffTime")
    def knowledge_cutoff_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        """
        return pulumi.get(self, "knowledge_cutoff_time")

    @knowledge_cutoff_time.setter
    def knowledge_cutoff_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "knowledge_cutoff_time", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Full resource name:
        knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent resource where this source will be created.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "parent")

    @parent.setter
    def parent(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['KnowledgeAssistantKnowledgeSourceProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @source_type.setter
    def source_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_type", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("databricks:index/knowledgeAssistantKnowledgeSource:KnowledgeAssistantKnowledgeSource")
class KnowledgeAssistantKnowledgeSource(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 file_table: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFileTableArgs', 'KnowledgeAssistantKnowledgeSourceFileTableArgsDict']]] = None,
                 files: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFilesArgs', 'KnowledgeAssistantKnowledgeSourceFilesArgsDict']]] = None,
                 index: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceIndexArgs', 'KnowledgeAssistantKnowledgeSourceIndexArgsDict']]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]] = None,
                 source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KnowledgeAssistantKnowledgeSourceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Beta](https://img.shields.io/badge/Release_Stage-Public_Beta-orange)](https://docs.databricks.com/aws/en/release-notes/release-types)

        :param str resource_name: The name of the resource.
        :param KnowledgeAssistantKnowledgeSourceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KnowledgeAssistantKnowledgeSourceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 file_table: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFileTableArgs', 'KnowledgeAssistantKnowledgeSourceFileTableArgsDict']]] = None,
                 files: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFilesArgs', 'KnowledgeAssistantKnowledgeSourceFilesArgsDict']]] = None,
                 index: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceIndexArgs', 'KnowledgeAssistantKnowledgeSourceIndexArgsDict']]] = None,
                 parent: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]] = None,
                 source_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KnowledgeAssistantKnowledgeSourceArgs.__new__(KnowledgeAssistantKnowledgeSourceArgs)

            if description is None and not opts.urn:
                raise TypeError("Missing required property 'description'")
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["file_table"] = file_table
            __props__.__dict__["files"] = files
            __props__.__dict__["index"] = index
            if parent is None and not opts.urn:
                raise TypeError("Missing required property 'parent'")
            __props__.__dict__["parent"] = parent
            __props__.__dict__["provider_config"] = provider_config
            if source_type is None and not opts.urn:
                raise TypeError("Missing required property 'source_type'")
            __props__.__dict__["source_type"] = source_type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["knowledge_cutoff_time"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["state"] = None
        super(KnowledgeAssistantKnowledgeSource, __self__).__init__(
            'databricks:index/knowledgeAssistantKnowledgeSource:KnowledgeAssistantKnowledgeSource',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            file_table: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFileTableArgs', 'KnowledgeAssistantKnowledgeSourceFileTableArgsDict']]] = None,
            files: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceFilesArgs', 'KnowledgeAssistantKnowledgeSourceFilesArgsDict']]] = None,
            index: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceIndexArgs', 'KnowledgeAssistantKnowledgeSourceIndexArgsDict']]] = None,
            knowledge_cutoff_time: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            parent: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']]] = None,
            source_type: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'KnowledgeAssistantKnowledgeSource':
        """
        Get an existing KnowledgeAssistantKnowledgeSource resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - Timestamp when this knowledge source was created
        :param pulumi.Input[_builtins.str] description: Description of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] display_name: Human-readable display name of the knowledge source.
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, optional unless included in update_mask
        :param pulumi.Input[_builtins.str] knowledge_cutoff_time: (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        :param pulumi.Input[_builtins.str] name: (string) - Full resource name:
               knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        :param pulumi.Input[_builtins.str] parent: Parent resource where this source will be created.
               Format: knowledge-assistants/{knowledge_assistant_id}
        :param pulumi.Input[Union['KnowledgeAssistantKnowledgeSourceProviderConfigArgs', 'KnowledgeAssistantKnowledgeSourceProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider.
        :param pulumi.Input[_builtins.str] source_type: The type of the source: "index", "files", or "file_table".
               Required when creating a Knowledge Source.
               When updating a Knowledge Source, this field is ignored
        :param pulumi.Input[_builtins.str] state: (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KnowledgeAssistantKnowledgeSourceState.__new__(_KnowledgeAssistantKnowledgeSourceState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["file_table"] = file_table
        __props__.__dict__["files"] = files
        __props__.__dict__["index"] = index
        __props__.__dict__["knowledge_cutoff_time"] = knowledge_cutoff_time
        __props__.__dict__["name"] = name
        __props__.__dict__["parent"] = parent
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["source_type"] = source_type
        __props__.__dict__["state"] = state
        return KnowledgeAssistantKnowledgeSource(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Timestamp when this knowledge source was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Description of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        Human-readable display name of the knowledge source.
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, optional unless included in update_mask
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="fileTable")
    def file_table(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceFileTable']]:
        return pulumi.get(self, "file_table")

    @_builtins.property
    @pulumi.getter
    def files(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceFiles']]:
        return pulumi.get(self, "files")

    @_builtins.property
    @pulumi.getter
    def index(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceIndex']]:
        return pulumi.get(self, "index")

    @_builtins.property
    @pulumi.getter(name="knowledgeCutoffTime")
    def knowledge_cutoff_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Timestamp representing the cutoff before which content in this knowledge source is being ingested
        """
        return pulumi.get(self, "knowledge_cutoff_time")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Full resource name:
        knowledge-assistants/{knowledge_assistant_id}/knowledge-sources/{knowledge_source_id}
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> pulumi.Output[_builtins.str]:
        """
        Parent resource where this source will be created.
        Format: knowledge-assistants/{knowledge_assistant_id}
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.KnowledgeAssistantKnowledgeSourceProviderConfig']]:
        """
        Configure the provider for management through account provider.
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="sourceType")
    def source_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the source: "index", "files", or "file_table".
        Required when creating a Knowledge Source.
        When updating a Knowledge Source, this field is ignored
        """
        return pulumi.get(self, "source_type")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Possible values are: `FAILED_UPDATE`, `UPDATED`, `UPDATING`
        """
        return pulumi.get(self, "state")

